<?php
/**
 * Popular Destination section
 *
 * This is the template for the content of popular destination section
 *
 * @package Theme Palace
 * @subpackage Travel Base Pro
 * @since Travel Base Pro 1.0.0
 */
if ( ! function_exists( 'travel_base_pro_add_popular_destination_section' ) ) :
    /**
    * Add popular destination section
    *
    *@since Travel Base Pro 1.0.0
    */
    function travel_base_pro_add_popular_destination_section() {
    	$options = travel_base_pro_get_theme_options();
        // Check if destination is enabled on frontpage
        $popular_destination_enable = apply_filters( 'travel_base_pro_section_status', true, 'popular_destination_section_enable' );

        if ( true !== $popular_destination_enable ) {
            return false;
        }
        // Get destination section details
        $section_details = array();
        $section_details = apply_filters( 'travel_base_pro_filter_popular_destination_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render destination section now.
        travel_base_pro_render_popular_destination_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_base_pro_get_popular_destination_section_details' ) ) :
    /**
    * popular destination section details.
    *
    * @since Travel Base Pro 1.0.0
    * @param array $input popular destination section details.
    */
    function travel_base_pro_get_popular_destination_section_details( $input ) {
        $options = travel_base_pro_get_theme_options();

        // Content type.
        $popular_destination_content_type  = $options['popular_destination_content_type'];
        $popular_destination_count = 3;
        
        $content = array();
        switch ( $popular_destination_content_type ) {
        	
            case 'category':
                $cat_id = ! empty( $options['popular_destination_content_category'] ) ? $options['popular_destination_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_destination_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $popular_destination_count; $i++ ) {
                    if ( ! empty( $options['popular_destination_content_page_' . $i] ) )
                        $page_ids[] = $options['popular_destination_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_destination_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $popular_destination_count; $i++ ) {
                    if ( ! empty( $options['popular_destination_content_post_' . $i] ) )
                        $post_ids[] = $options['popular_destination_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_destination_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $page_ids = array();

                for ( $i = 1; $i <= $popular_destination_count; $i++ ) {
                    if ( ! empty( $options['popular_destination_content_trip_' . $i] ) )
                        $page_ids[] = $options['popular_destination_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_destination_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'trip-types':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['popular_destination_content_trip_types'] ) ? $options['popular_destination_content_trip_types'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $popular_destination_count ),
                    );                    
            break;

            case 'destination':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['popular_destination_content_destination'] ) ? $options['popular_destination_content_destination'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $popular_destination_count ),
                    );                    
            break;

            case 'activity':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['popular_destination_content_activity'] ) ? $options['popular_destination_content_activity'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $popular_destination_count ),
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = travel_base_pro_trim_content( 25 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// destination section content details.
add_filter( 'travel_base_pro_filter_popular_destination_section_details', 'travel_base_pro_get_popular_destination_section_details' );


if ( ! function_exists( 'travel_base_pro_render_popular_destination_section' ) ) :
  /**
   * Start destination section
   *
   * @return string destination content
   * @since Travel Base Pro 1.0.0
   *
   */
   function travel_base_pro_render_popular_destination_section( $content_details = array() ) {
        $options = travel_base_pro_get_theme_options();
        $popular_destination_content_type  = $options['popular_destination_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="popular-destinations" class="relative page-section">
            <div class="wrapper">
                <div class="section-content clear">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="destination-item-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <?php if ( in_array( $popular_destination_content_type, array( 'trip', 'trip-types', 'destination', 'activity' ) ) ) :
                                    $sale_enabled = get_post_meta( $content['id'], 'wp_travel_enable_sale', true );
                                    if ( false !== $sale_enabled && '1' === $sale_enabled ) : ?>
                                    <div class="wp-travel-offer">
                                        <span><?php esc_html_e( 'Offer', 'travel-base-pro' ); ?></span>
                                    </div>
                                <?php endif; endif;?> 
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <div class="entry-container-wrap">
                                        <?php if ( in_array( $popular_destination_content_type, array( 'post', 'category' ) ) ) : ?>
                                            <span class="trip-category">
                                                <?php the_category( ' ', '', $content['id'] ); ?>
                                            </span>
                                        <?php elseif ( in_array( $popular_destination_content_type, array( 'trip', 'trip-types', 'destination', 'activity' ) ) ) :
                                            $terms = wp_get_post_terms( $content['id'], 'travel_locations' ); ?>
                                            <span class="trip-category">
                                                <?php foreach ( $terms as $term ) : ?>
                                                    <a href="<?php echo esc_url( get_term_link( $term->term_id, 'travel_locations' ) ); ?>"><?php echo esc_html( $term->name ); ?></a>
                                                <?php endforeach; ?>
                                            </span>
                                        <?php endif; ?>

                                        <h4 class="post-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h4>

                                        <?php if ( ! in_array( $popular_destination_content_type, array( 'category', 'page', 'post' ) ) ) : 
                                            $sale_enabled = get_post_meta( $content['id'], 'wp_travel_enable_sale', true );
                                            $trip_price = WP_Travel_Helpers_Pricings::get_price(array('trip_id'=>$content['id']));
                                            ?>
                                            
                                            <div class="clearfix">

                                                <?php if ( travel_base_pro_wptravel_tab_show_in_menu( 'reviews' ) ) :
                                                    $average_rating = travel_base_pro_wptravel_get_average_rating( $content['id'] ); ?>
                                                        <div class="wp-travel-average-review" title="<?php printf( esc_attr__( 'Rated %s out of 5', 'travel-base-pro' ), $average_rating ); ?>">
                                                            <span style="width:<?php echo esc_attr( ( $average_rating / 5 ) * 100 ); ?>%">
                                                                <strong itemprop="ratingValue" class="rating"><?php echo esc_html( $average_rating ); ?></strong> <?php printf( esc_html__( 'out of %1$s5%2$s', 'travel-base-pro' ), '<span itemprop="bestRating">', '</span>' ); ?>
                                                            </span>
                                                        </div>
                                                <?php endif; ?>
                                            </div><!-- .clearfix -->
                                        <?php endif; ?>

                                        <div class="entry-content">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container-wrap -->
                                    
                                    <?php if ( ! in_array( $popular_destination_content_type, array( 'category', 'page', 'post' ) ) ) : ?>
                                        <div class="trip-metas clear">
                                            <div class="wp-travel-trip-time trip-duration">
                                                <h5 class="trip-meta-title"><?php echo esc_html__( 'Duration', 'travel-base-pro' ); ?></h5>
                                                <i class="fa fa-clock-o"></i>
                                                <span class="wp-travel-trip-duration"><?php travel_base_pro_trip_duration( $content['id'] ); ?></span>
                                            </div><!-- .wp-travel-trip-time.trip-duration -->

                                            <div class="trip-difficulty">
                                                <h5 class="trip-meta-title"><?php echo esc_html__( 'Price', 'travel-base-pro' ); ?></h5>
                                                <span>
                                                    <?php 
                                                        echo travel_base_pro_wptravel_get_formated_price_currency( $trip_price );
                                                    ?>
                                                </span>
                                            </div><!-- .wp-travel-trip-time.trip-duration -->
                                        </div><!-- .trip-metas -->
                                    <?php endif; ?>
                                </div><!-- .entry-container -->
                            </div><!-- .destination-item-wrapper -->
                        </article>
                    <?php endforeach; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #popular-destinations -->
        
    <?php }
endif;